@@ -415,7 +415,6 @@ class Store:
         handler = self.get_handler_for_item_type_name(item_type_name)
         if handler is not None:
             handler.parse_document_fragment(doc, doc_root, uriref=uriref)
-            self.commit()
 
     def remove_item(self, item, deep=0):
 
@@ -424,7 +423,6 @@ class Store:
         handler = self.get_handler(item)
         if handler is not None:
             handler.remove_node(item, deep)
-            self.commit()
 
     def has_item(self, item):
 
@@ -667,7 +665,7 @@ class Store:
 
         # Or use type-based criteria.
 
-        if attributes.has_key("item-type"):
+        if attributes.has_key("item-type") and attributes["item-type"] != "all":
             item_types = [attributes["item-type"]]
         else:
             item_types = self.default_item_types
