@@ -36,8 +36,6 @@ class CalendarViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
     "A calendar viewer."
 
     resource_dir = os.path.join(os.path.split(__file__)[0], "Resources")
-    encoding = "utf-8"
-    path_encoding = "utf-8"
     template_resources = {
         "items_calendar" : ("items_calendar_template.xhtml", "items_calendar_output.xsl")
         }
@@ -63,8 +61,8 @@ class CalendarViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
         # Get paths, specifically the parent, since this will be used to
         # redirect to new resource editors.
 
-        pvpath = trans.get_processed_virtual_path_info(self.path_encoding)
-        ppath = trans.get_path_without_info(self.path_encoding) + pvpath
+        pvpath = trans.get_processed_virtual_path_info()
+        ppath = trans.get_path_without_info() + pvpath
 
         # Get the items in the form.
 
@@ -89,7 +87,7 @@ class CalendarViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
 
         parameters = form.get_parameters()
         if parameters.has_key("download-all"):
-            trans.set_content_type(ContentType("text/calendar", self.encoding))
+            trans.set_content_type(ContentType("text/calendar"))
             stream = trans.get_response_stream()
             export_items(found_items, self.store, stream)
             raise EndOfResponse
@@ -97,7 +95,7 @@ class CalendarViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
         elif parameters.has_key("new"):
             new_type = items.xpath("items/new-type/@value")[0].nodeValue
             new_path = trans.update_path(ppath, "../%s/new/" % new_type)
-            trans.redirect(trans.encode_path(new_path, self.path_encoding))
+            trans.redirect(trans.encode_path(new_path))
             # Response ended!
 
         # Produce a new document.
@@ -126,7 +124,7 @@ class CalendarViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
 
         # Start the response.
 
-        trans.set_content_type(ContentType("application/xhtml+xml", self.encoding))
+        trans.set_content_type(ContentType("application/xhtml+xml"))
 
         # Define the stylesheet parameters.
 
@@ -167,8 +165,6 @@ class ListViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
     "An item list viewer."
 
     resource_dir = os.path.join(os.path.split(__file__)[0], "Resources")
-    encoding = "utf-8"
-    path_encoding = "utf-8"
     template_resources = {
         "items" : ("items_template.xhtml", "items_output.xsl")
         }
@@ -194,8 +190,8 @@ class ListViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
         # Get paths, specifically the parent, since this will be used to
         # redirect to new resource editors.
 
-        pvpath = trans.get_processed_virtual_path_info(self.path_encoding)
-        ppath = trans.get_path_without_info(self.path_encoding) + pvpath
+        pvpath = trans.get_processed_virtual_path_info()
+        ppath = trans.get_path_without_info() + pvpath
 
         # Get the items in the form.
 
@@ -207,7 +203,7 @@ class ListViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
 
         # Get other settings.
 
-        fields = trans.get_fields_from_path(self.path_encoding)
+        fields = trans.get_fields_from_path()
         attributes = trans.get_attributes()
 
         # Initialise certain settings.
@@ -241,13 +237,13 @@ class ListViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
         parameters = form.get_parameters()
 
         if parameters.has_key("download-all"):
-            trans.set_content_type(ContentType("text/calendar", self.encoding))
+            trans.set_content_type(ContentType("text/calendar"))
             stream = trans.get_response_stream()
             export_items(found_items, self.store, stream)
             raise EndOfResponse
 
         elif parameters.has_key("download"):
-            trans.set_content_type(ContentType("text/calendar", self.encoding))
+            trans.set_content_type(ContentType("text/calendar"))
             stream = trans.get_response_stream()
             export_items(selected_items, self.store, stream)
             raise EndOfResponse
@@ -255,7 +251,7 @@ class ListViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
         elif parameters.has_key("new"):
             new_type = items.xpath("items/new-type/@value")[0].nodeValue
             new_path = trans.update_path(ppath, "../%s/new/" % new_type)
-            trans.redirect(trans.encode_path(new_path, self.path_encoding))
+            trans.redirect(trans.encode_path(new_path))
             # Response ended!
 
         # Produce a new document.
@@ -290,7 +286,7 @@ class ListViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
 
         # Start the response.
 
-        trans.set_content_type(ContentType("application/xhtml+xml", self.encoding))
+        trans.set_content_type(ContentType("application/xhtml+xml"))
 
         # Define the stylesheet parameters.
 
@@ -327,7 +323,6 @@ class PropertyViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
     """
 
     resource_dir = os.path.join(os.path.split(__file__)[0], "Resources")
-    encoding = "utf-8"
     template_resources = {
         "items" : ("items_properties_template.xml", "items_properties_output.xsl")
         }
@@ -346,10 +341,10 @@ class PropertyViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
 
         # Get the processed path details and a version suitable for output.
 
-        pvpath = trans.get_processed_virtual_path_info(self.path_encoding)
-        ppath = trans.get_path_without_info(self.path_encoding) + pvpath
-        encoded_pvpath = "/".join([trans.encode_path(part, self.path_encoding) for part in pvpath.split("/")])
-        encoded_ppath = trans.get_path_without_info(self.path_encoding) + encoded_pvpath
+        pvpath = trans.get_processed_virtual_path_info()
+        ppath = trans.get_path_without_info() + pvpath
+        encoded_pvpath = "/".join([trans.encode_path(part) for part in pvpath.split("/")])
+        encoded_ppath = trans.get_path_without_info() + encoded_pvpath
 
         # Obtain information relevant to the item search.
 
@@ -412,7 +407,7 @@ class PropertyViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
 
         # Start the response.
 
-        trans.set_content_type(ContentType("application/xml", self.encoding))
+        trans.set_content_type(ContentType("application/xml"))
 
         # Define the stylesheet parameters.
 
@@ -438,7 +433,6 @@ class SimpleViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
     """
 
     resource_dir = os.path.join(os.path.split(__file__)[0], "Resources")
-    encoding = "utf-8"
 
     def respond_to_form(self, trans, form):
 
@@ -451,10 +445,10 @@ class SimpleViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
 
         # Get the processed path details and a version suitable for output.
 
-        pvpath = trans.get_processed_virtual_path_info(self.path_encoding)
-        ppath = trans.get_path_without_info(self.path_encoding) + pvpath
-        encoded_pvpath = "/".join([trans.encode_path(part, self.path_encoding) for part in pvpath.split("/")])
-        encoded_ppath = trans.get_path_without_info(self.path_encoding) + encoded_pvpath
+        pvpath = trans.get_processed_virtual_path_info()
+        ppath = trans.get_path_without_info() + pvpath
+        encoded_pvpath = "/".join([trans.encode_path(part) for part in pvpath.split("/")])
+        encoded_ppath = trans.get_path_without_info() + encoded_pvpath
 
         # Invent a document based on the resources.
 
@@ -471,7 +465,7 @@ class SimpleViewerResource(XSLForms.Resources.WebResources.XSLFormsResource):
 
         # Start the response.
 
-        trans.set_content_type(ContentType("application/xml", self.encoding))
+        trans.set_content_type(ContentType("application/xml"))
 
         # Define the stylesheet parameters.
 
