@@ -21,14 +21,14 @@ If not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 """
 
-__version__ = "0.2.3"
+__version__ = "0.2.4"
 
 import os
 
 # Site map imports.
 
 from WebStack.Resources.ResourceMap import MapResource
-from WebStack.Resources.Selectors import PathSelector
+from WebStack.Resources.Selectors import EncodingSelector, PathSelector
 from WebStack.Resources.Static import DirectoryResource
 from WebCalendar.Viewer import *
 from WebCalendar.Selector import *
@@ -38,7 +38,7 @@ from WebCalendar.Importer import *
 
 # Important constants.
 
-encoding = "utf-8"
+from WebCalendar.Common import encoding
 
 # Site map initialisation.
 
@@ -94,7 +94,7 @@ def get_site(store):
     view_choices = MapResource({
         "" : ViewSelectorResource(list_viewer_resource, calendar_viewer_resource, prop_viewer_resource),
         None : ItemSelectorResource(editor_resource, item_importer_resource, item_exporter_resource, prop_viewer_resource)
-        }, path_encoding=encoding) # not pass_through: identifiers are removed from the vpath
+        }) # not pass_through: identifiers are removed from the vpath
 
     item_choices = MapResource({
         # Exporters...
@@ -105,7 +105,7 @@ def get_site(store):
         # Views...
         "all" : view_choices,
         "" : TopSelectorResource("all/", webdav_root)
-        }, pass_through=1, path_encoding=encoding)
+        }, pass_through=1)
 
     # Add type-based handlers, dependent on what the store offers.
 
@@ -118,22 +118,25 @@ def get_site(store):
         "person" : FilterSelectorResource("person", item_choices, prop_viewer_resource, "card"),
         # Pass through...
         None : item_choices
-        }, pass_through=1, path_encoding=encoding)
+        }, pass_through=1)
 
     date_choices = MapResource({
         "date" : DateSelectorResource(filter_choices, webdav_months),
         # Pass through...
         None : filter_choices
-        }, pass_through=1, path_encoding=encoding)
+        }, pass_through=1)
 
     root_choices = MapResource({
         "styles" : styles_dir,
         "scripts" : scripts_dir,
         "images" : images_dir,
         None : date_choices
-        }, pass_through=1, path_encoding=encoding)
+        }, pass_through=1)
 
-    return OptionsSelectorResource(PathSelector(root_choices))
+    return EncodingSelector(
+        OptionsSelectorResource(PathSelector(root_choices)),
+        encoding
+        )
 
 # Resource preparation ahead of time - useful for making installations.
 
