@@ -38,13 +38,13 @@ icon_sets = {
         ("actions", "down", "sort-ascending"),
         ("actions", "up", "sort-descending"),
         ("actions", "filenew", "created"),
+        ("apps", "kwrite2", "updated"),
         ("apps", "clock", "appointment"),
         ("actions", "redo", "continued"),
         ("filesystems", "folder", None)
         ],
     CRYSTAL_CLEAR : [
         ("mimetypes", "vcard", "card"),
-        #("actions", "edit", None),
         ("actions", "viewmag", "search"),
         ("actions", "easymoblog", "journal"),
         ("actions", "mail_generic", "e-mail"),
@@ -55,6 +55,7 @@ icon_sets = {
         ("actions", "down", "sort-ascending"),
         ("actions", "up", "sort-descending"),
         ("mimetypes", "empty", "created"),
+        ("actions", "edit", "updated"),
         ("apps", "xclock", "appointment"),
         ("actions", "redo", "continued"),
         ("filesystems", "folder", None)
@@ -71,6 +72,7 @@ icon_sets = {
         ("actions", "go-down", "sort-ascending"),
         ("actions", "go-up", "sort-descending"),
         ("actions", "document-new", "created"),
+        ("actions", "document-open", "updated"),
         ("actions", "appointment", None),
         ("actions", "go-jump", "continued"),
         ("places", "folder", None)
